nereid-cms
==========

.. image:: https://travis-ci.org/fulfilio/nereid-cms.png?branch=develop
  :target: https://travis-ci.org/fulfilio/nereid-cms

.. image:: https://coveralls.io/repos/fulfilio/nereid-cms/badge.png?branch=develop
  :target: https://coveralls.io/r/fulfilio/nereid-cms
